aboutsummaryrefslogtreecommitdiff
path: root/src/main/java/org/traccar/config/Keys.java
diff options
context:
space:
mode:
authorEdward Valley <ed.valley@yandex.com>2020-02-15 20:23:08 -0500
committerEdward Valley <ed.valley@yandex.com>2020-02-15 20:23:08 -0500
commitf8c83c4f7f517b7482bdf7f29a3704903b876855 (patch)
tree9c7c007cbab013b3804b9d7568877992cde8e20f /src/main/java/org/traccar/config/Keys.java
parent3c71ac47b4515fb799e67a18b18d722bea4d2241 (diff)
downloadtraccar-server-f8c83c4f7f517b7482bdf7f29a3704903b876855.tar.gz
traccar-server-f8c83c4f7f517b7482bdf7f29a3704903b876855.tar.bz2
traccar-server-f8c83c4f7f517b7482bdf7f29a3704903b876855.zip
Changes after review
Diffstat (limited to 'src/main/java/org/traccar/config/Keys.java')
-rw-r--r--src/main/java/org/traccar/config/Keys.java32
1 files changed, 16 insertions, 16 deletions
diff --git a/src/main/java/org/traccar/config/Keys.java b/src/main/java/org/traccar/config/Keys.java
index 999a1d6df..d88b36d28 100644
--- a/src/main/java/org/traccar/config/Keys.java
+++ b/src/main/java/org/traccar/config/Keys.java
@@ -101,35 +101,35 @@ public final class Keys {
"forward.json", Boolean.class);
/**
* Position forwarding retrying enable. When enabled, additional attempts are made to deliver positions.
* If initial delivery fails, because of an unreachable server or an HTTP response different from '200 OK',
* the software waits for 'forward.retry.delay.min' seconds to retry delivery. On subsequent failures, this
* delay is incremented by 1 second up to 'forward.retry.delay.max'. Positions pending to be delivered
* are limited to 'forward.retry.pending.limit'. If this limit is reached, positions get discarded.
*/
public static final ConfigKey FORWARD_RETRY_ENABLE = new ConfigKey(
"forward.retry.enable", Boolean.class);
/**
- * Position forwarding retry minimum delay in seconds.
- * Can be set to anything greater than 0. Defaults to 1 second.
+ * Position forwarding retry first delay in milliseconds.
+ * Can be set to anything greater than 0. Defaults to 100 milliseconds.
*/
- public static final ConfigKey FORWARD_RETRY_DELAY_MIN = new ConfigKey(
- "forward.retry.delay.min", Integer.class);
+ public static final ConfigKey FORWARD_RETRY_DELAY = new ConfigKey(
+ "forward.retry.delay", Integer.class);
/**
- * Position forwarding retry maximum delay in seconds.
- * Can be set to anything greater than 0. Defaults to 10 seconds.
+ * Position forwarding retry maximum retries.
+ * Can be set to anything greater than 0. Defaults to 10 retries.
*/
- public static final ConfigKey FORWARD_RETRY_DELAY_MAX = new ConfigKey(
- "forward.retry.delay.max", Integer.class);
+ public static final ConfigKey FORWARD_RETRY_COUNT = new ConfigKey(
+ "forward.retry.count", Integer.class);
/**
- * Position forwarding retry pending limit.
+ * Position forwarding retry pending positions limit.
* Can be set to anything greater than 0. Defaults to 100 positions.
*/
- public static final ConfigKey FORWARD_RETRY_PENDING_LIMIT = new ConfigKey(
- "forward.retry.pending.limit", Integer.class);
+ public static final ConfigKey FORWARD_RETRY_LIMIT = new ConfigKey(
+ "forward.retry.limit", Integer.class);
/**
* Boolean flag to enable or disable position filtering.
@@ -101,35 +101,35 @@ public final class Keys {
"forward.json", Boolean.class);
/**
- * Position forwarding retrying enable. When enabled, additional attempts are made to deliver positions.
- * If initial delivery fails, because of an unreachable server or an HTTP response different from '200 OK',
- * the software waits for 'forward.retry.delay.min' seconds to retry delivery. On subsequent failures, this
- * delay is incremented by 1 second up to 'forward.retry.delay.max'. Positions pending to be delivered
- * are limited to 'forward.retry.pending.limit'. If this limit is reached, positions get discarded.
+ * Position forwarding retrying enable. When enabled, additional attempts are made to deliver positions. If initial
+ * delivery fails, because of an unreachable server or an HTTP response different from '2xx', the software waits
+ * for 'forward.retry.delay' milliseconds to retry delivery. On subsequent failures, this delay is duplicated.
+ * If forwarding is retried for 'forward.retry.count', retrying is canceled and the position is dropped. Positions
+ * pending to be delivered are limited to 'forward.retry.limit'. If this limit is reached, positions get discarded.
*/
public static final ConfigKey FORWARD_RETRY_ENABLE = new ConfigKey(